
# Class: CodeSystem




URI: [ks:CodeSystem](https://w3id.org/linkml/tests/kitchen_sink/CodeSystem)


[![img](https://yuml.me/diagram/nofunky;dir:TB/class/[Dataset]++-%20code%20systems%200..*>[CodeSystem&#124;id:string;name:string%20%3F],[Concept]-%20in%20code%20system%200..1>[CodeSystem],[Dataset],[Concept])](https://yuml.me/diagram/nofunky;dir:TB/class/[Dataset]++-%20code%20systems%200..*>[CodeSystem&#124;id:string;name:string%20%3F],[Concept]-%20in%20code%20system%200..1>[CodeSystem],[Dataset],[Concept])

## Referenced by Class

 *  **None** *[➞code systems](dataset__code_systems.md)*  <sub>0..\*</sub>  **[CodeSystem](CodeSystem.md)**
 *  **None** *[in code system](in_code_system.md)*  <sub>0..1</sub>  **[CodeSystem](CodeSystem.md)**

## Attributes


### Own

 * [id](id.md)  <sub>1..1</sub>
     * Range: [String](types/String.md)
 * [name](name.md)  <sub>0..1</sub>
     * Range: [String](types/String.md)
